==> udata-1.1.7-py2.py3-none-any.whl: udata/harvest/tests/factories.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import factory

from factory.fuzzy import FuzzyChoice
from flask.signals import Namespace
from mock import patch

from udata.core.dataset.factories import DatasetFactory

from .. import backends
from ..models import HarvestSource, HarvestJob


def dtfactory(start, end):
    return factory.Faker('date_time_between', start_date=start, end_date=end)


class HarvestSourceFactory(factory.mongoengine.MongoEngineFactory):
    class Meta:
        model = HarvestSource

    name = factory.Faker('name')
    url = factory.Faker('url')
    description = factory.Faker('text')


class HarvestJobFactory(factory.mongoengine.MongoEngineFactory):
    class Meta:
        model = HarvestJob

    created = dtfactory('-3h', '-2h')
    started = dtfactory('-2h', '-1h')
    ended = dtfactory('-1h', 'now')
    status = FuzzyChoice(HarvestJob.status.choices)
    source = factory.SubFactory(HarvestSourceFactory)


ns = Namespace()

mock_initialize = ns.signal('backend:initialize')
mock_process = ns.signal('backend:process')

DEFAULT_COUNT = 3


class FactoryBackend(backends.BaseBackend):
    name = 'factory'

    def initialize(self):
        mock_initialize.send(self)
        for i in range(self.config.get('count', DEFAULT_COUNT)):
            self.add_item(i)

    def process(self, item):
        mock_process.send(self, item=item)
        return DatasetFactory.build(title='dataset-{0}'.format(item.remote_id))


class MockBackendsMixin(object):
    '''A mixin mocking the harvest backend'''
    def setUp(self):
        super(MockBackendsMixin, self).setUp()
        self.patcher = patch('udata.harvest.backends.get_all')
        mock_get_all = self.patcher.start()
        mock_get_all.return_value = {'factory': FactoryBackend}

    def tearDown(self):
        super(MockBackendsMixin, self).tearDown()
        self.patcher.stop()

==> udata-1.2.7-py2.py3-none-any.whl: udata/harvest/tests/factories.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import factory

from factory.fuzzy import FuzzyChoice
from flask.signals import Namespace
from mock import patch

from udata.factories import ModelFactory
from udata.core.dataset.factories import DatasetFactory

from .. import backends
from ..models import HarvestSource, HarvestJob


def dtfactory(start, end):
    return factory.Faker('date_time_between', start_date=start, end_date=end)


class HarvestSourceFactory(ModelFactory):
    class Meta:
        model = HarvestSource

    name = factory.Faker('name')
    url = factory.Faker('url')
    description = factory.Faker('text')


class HarvestJobFactory(ModelFactory):
    class Meta:
        model = HarvestJob

    created = dtfactory('-3h', '-2h')
    started = dtfactory('-2h', '-1h')
    ended = dtfactory('-1h', 'now')
    status = FuzzyChoice(HarvestJob.status.choices)
    source = factory.SubFactory(HarvestSourceFactory)


ns = Namespace()

mock_initialize = ns.signal('backend:initialize')
mock_process = ns.signal('backend:process')

DEFAULT_COUNT = 3


class FactoryBackend(backends.BaseBackend):
    name = 'factory'

    def initialize(self):
        mock_initialize.send(self)
        for i in range(self.config.get('count', DEFAULT_COUNT)):
            self.add_item(i)

    def process(self, item):
        mock_process.send(self, item=item)
        return DatasetFactory.build(title='dataset-{0}'.format(item.remote_id))


class MockBackendsMixin(object):
    '''A mixin mocking the harvest backend'''
    def setUp(self):
        super(MockBackendsMixin, self).setUp()
        self.patcher = patch('udata.harvest.backends.get_all')
        mock_get_all = self.patcher.start()
        mock_get_all.return_value = {'factory': FactoryBackend}

    def tearDown(self):
        super(MockBackendsMixin, self).tearDown()
        self.patcher.stop()
